@@ -153,7 +153,7 @@ static void testLocalFile(const QString &filename)
     }
 }
 
-static char s_delimiter = ':'; // the alternative is ' '
+static const char s_delimiter = WEBSHORTCUT_SEPARATOR;
 
 void KUriFilterTest::initTestCase()
 {
@@ -172,12 +172,6 @@ void KUriFilterTest::initTestCase()
     QVERIFY(!searchProvidersDir.isEmpty());
     qputenv("KIO_SEARCHPROVIDERS_DIR", QFile::encodeName(searchProvidersDir));
 
-    // Allow testing of the search engine using both delimiters...
-    const char *envDelimiter = ::getenv("KURIFILTERTEST_DELIMITER");
-    if (envDelimiter) {
-        s_delimiter = envDelimiter[0];
-    }
-
     // Many tests check the "default search engine" feature.
     // There is no default search engine by default (since it was annoying when making typos),
     // so the user has to set it up, which we do here.
@@ -221,12 +215,8 @@ void KUriFilterTest::noFiltering_data()
     setupColumns();
     // URI that should require no filtering
     addRow("http://www.kde.org", QStringLiteral("http://www.kde.org"), KUriFilterData::NetProtocol);
-#if QT_VERSION >= QT_VERSION_CHECK(5, 12, 1)
     // qtbase commit eaf4438b3511c preserves the double slashes
     addRow("http://www.kde.org/developer//index.html", QStringLiteral("http://www.kde.org/developer//index.html"), KUriFilterData::NetProtocol);
-#else
-    addRow("http://www.kde.org/developer//index.html", QStringLiteral("http://www.kde.org/developer/index.html"), KUriFilterData::NetProtocol);
-#endif
     addRow("file:///", QStringLiteral("/"), KUriFilterData::LocalDir);
     addRow("file:///etc", QStringLiteral("/etc"), KUriFilterData::LocalDir);
     addRow("file:///etc/passwd", QStringLiteral("/etc/passwd"), KUriFilterData::LocalFile);
@@ -299,14 +289,9 @@ void KUriFilterTest::shortUris_data()
 {
     setupColumns();
     // hostnames are lowercased by QUrl
-#if QT_VERSION >= QT_VERSION_CHECK(5, 12, 1)
     // qtbase commit eaf4438b3511c preserves the double slashes
     addRow("http://www.myDomain.commyPort/ViewObjectRes//Default:name=hello",
            QStringLiteral("http://www.mydomain.commyport/ViewObjectRes//Default:name=hello"), KUriFilterData::NetProtocol);
-#else
-    addRow("http://www.myDomain.commyPort/ViewObjectRes//Default:name=hello",
-           QStringLiteral("http://www.mydomain.commyport/ViewObjectRes/Default:name=hello"), KUriFilterData::NetProtocol);
-#endif
     addRow("http://www.myDomain.commyPort/ViewObjectRes/Default:name=hello?a=a///////",
            QStringLiteral("http://www.mydomain.commyport/ViewObjectRes/Default:name=hello?a=a///////"), KUriFilterData::NetProtocol);
     addRow("ftp://ftp.kde.org", QStringLiteral("ftp://ftp.kde.org"), KUriFilterData::NetProtocol);
@@ -456,6 +441,9 @@ void KUriFilterTest::internetKeywords_data()
 {
     setupColumns();
     addRow(QString::asprintf("gg%cfoo bar", s_delimiter).toUtf8(), QStringLiteral("https://www.google.com/search?q=foo%20bar&ie=UTF-8"), KUriFilterData::NetProtocol);
+    addRow("!gg foo bar", QStringLiteral("https://www.google.com/search?q=foo%20bar&ie=UTF-8"), KUriFilterData::NetProtocol);
+    addRow("foo !gg bar", QStringLiteral("https://www.google.com/search?q=foo%20bar&ie=UTF-8"), KUriFilterData::NetProtocol);
+    addRow("foo bar!gg", QStringLiteral("https://www.google.com/search?q=foo%20bar&ie=UTF-8"), KUriFilterData::NetProtocol);
     addRow(QString::asprintf("bug%c55798", s_delimiter).toUtf8(), QStringLiteral("https://bugs.kde.org/buglist.cgi?quicksearch=55798"), KUriFilterData::NetProtocol);
 
     addRow(QString::asprintf("gg%cC++", s_delimiter).toUtf8(), QStringLiteral("https://www.google.com/search?q=C%2B%2B&ie=UTF-8"), KUriFilterData::NetProtocol);
@@ -476,7 +464,7 @@ void KUriFilterTest::localdomain()
     const QString host = QHostInfo::localHostName();
     if (host.isEmpty()) {
         const QString expected = QLatin1String("http://") + host;
-        runFilterTest(host, expected, KUriFilterData::NetProtocol, QStringList() << QStringLiteral("localdomainurifilter"), nullptr, false);
+        runFilterTest(host, expected, KUriFilterData::NetProtocol, QStringList{QStringLiteral("localdomainurifilter")}, nullptr, false);
     }
 }
 
