@@ -1,21 +1,9 @@
-/* This file is part of the KDE project
-   Copyright (C) 1999-2011 David Faure <faure@kde.org>
-   2001 Carsten Pfeiffer <pfeiffer@kde.org>
+/*
+    This file is part of the KDE project
+    SPDX-FileCopyrightText: 1999-2011 David Faure <faure@kde.org>
+    SPDX-FileCopyrightText: 2001 Carsten Pfeiffer <pfeiffer@kde.org>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "kfileitem.h"
@@ -27,21 +15,21 @@
 #include <QDate>
 #include <QDir>
 #include <QDirIterator>
-#include <QFile>
 #include <QDataStream>
 #include <QMimeDatabase>
 #include <QDebug>
-#include <qplatformdefs.h>
+#include <QLocale>
 
-#include <klocalizedstring.h>
-#include <kdesktopfile.h>
+#include <KLocalizedString>
+#include <KDesktopFile>
 #include <kmountpoint.h>
-#include <kconfiggroup.h>
+#include <KConfigGroup>
 #ifndef Q_OS_WIN
 #include <knfsshare.h>
 #include <ksambashare.h>
 #endif
-#include <kfilesystemtype.h>
+#include <KFileSystemType>
+#include <KProtocolManager>
 
 class KFileItemPrivate : public QSharedData
 {
@@ -383,19 +371,19 @@ bool KFileItemPrivate::cmp(const KFileItemPrivate &item) const
     }
 
 #if 0
-    //qDebug() << "Comparing" << m_url << "and" << item.m_url;
-    //qDebug() << " name" << (m_strName == item.m_strName);
-    //qDebug() << " local" << (m_bIsLocalUrl == item.m_bIsLocalUrl);
-    //qDebug() << " mode" << (m_fileMode == item.m_fileMode);
-    //qDebug() << " perm" << (m_permissions == item.m_permissions);
-    //qDebug() << " UDS_EXTENDED_ACL" << (m_entry.stringValue( KIO::UDSEntry::UDS_EXTENDED_ACL ) == item.m_entry.stringValue( KIO::UDSEntry::UDS_EXTENDED_ACL ));
-    //qDebug() << " UDS_ACL_STRING" << (m_entry.stringValue( KIO::UDSEntry::UDS_ACL_STRING ) == item.m_entry.stringValue( KIO::UDSEntry::UDS_ACL_STRING ));
-    //qDebug() << " UDS_DEFAULT_ACL_STRING" << (m_entry.stringValue( KIO::UDSEntry::UDS_DEFAULT_ACL_STRING ) == item.m_entry.stringValue( KIO::UDSEntry::UDS_DEFAULT_ACL_STRING ));
-    //qDebug() << " m_bLink" << (m_bLink == item.m_bLink);
-    //qDebug() << " m_hidden" << (m_hidden == item.m_hidden);
-    //qDebug() << " size" << (size() == item.size());
-    //qDebug() << " ModificationTime" << m_entry.numberValue(KIO::UDSEntry::UDS_MODIFICATION_TIME) << item.m_entry.numberValue(KIO::UDSEntry::UDS_MODIFICATION_TIME);
-    //qDebug() << " UDS_ICON_NAME" << (m_entry.stringValue( KIO::UDSEntry::UDS_ICON_NAME ) == item.m_entry.stringValue( KIO::UDSEntry::UDS_ICON_NAME ));
+    qDebug() << "Comparing" << m_url << "and" << item.m_url;
+    qDebug() << " name" << (m_strName == item.m_strName);
+    qDebug() << " local" << (m_bIsLocalUrl == item.m_bIsLocalUrl);
+    qDebug() << " mode" << (m_fileMode == item.m_fileMode);
+    qDebug() << " perm" << (m_permissions == item.m_permissions);
+    qDebug() << " UDS_EXTENDED_ACL" << (m_entry.stringValue( KIO::UDSEntry::UDS_EXTENDED_ACL ) == item.m_entry.stringValue( KIO::UDSEntry::UDS_EXTENDED_ACL ));
+    qDebug() << " UDS_ACL_STRING" << (m_entry.stringValue( KIO::UDSEntry::UDS_ACL_STRING ) == item.m_entry.stringValue( KIO::UDSEntry::UDS_ACL_STRING ));
+    qDebug() << " UDS_DEFAULT_ACL_STRING" << (m_entry.stringValue( KIO::UDSEntry::UDS_DEFAULT_ACL_STRING ) == item.m_entry.stringValue( KIO::UDSEntry::UDS_DEFAULT_ACL_STRING ));
+    qDebug() << " m_bLink" << (m_bLink == item.m_bLink);
+    qDebug() << " m_hidden" << (m_hidden == item.m_hidden);
+    qDebug() << " size" << (size() == item.size());
+    qDebug() << " ModificationTime" << m_entry.numberValue(KIO::UDSEntry::UDS_MODIFICATION_TIME) << item.m_entry.numberValue(KIO::UDSEntry::UDS_MODIFICATION_TIME);
+    qDebug() << " UDS_ICON_NAME" << (m_entry.stringValue( KIO::UDSEntry::UDS_ICON_NAME ) == item.m_entry.stringValue( KIO::UDSEntry::UDS_ICON_NAME ));
 #endif
     return (m_strName == item.m_strName
             && m_bIsLocalUrl == item.m_bIsLocalUrl
@@ -529,11 +517,13 @@ KFileItem::KFileItem(const KIO::UDSEntry &entry, const QUrl &itemOrDirUrl,
 {
 }
 
+#if KIOCORE_BUILD_DEPRECATED_SINCE(5, 0)
 KFileItem::KFileItem(mode_t mode, mode_t permissions, const QUrl &url, bool delayedMimeTypes)
     : d(new KFileItemPrivate(KIO::UDSEntry(), mode, permissions,
                              url, false, delayedMimeTypes, KFileItem::NormalMimeTypeDetermination))
 {
 }
+#endif
 
 KFileItem::KFileItem(const QUrl &url, const QString &mimeType, mode_t mode)
     : d(new KFileItemPrivate(KIO::UDSEntry(), mode, KFileItem::Unknown,
@@ -1202,11 +1192,11 @@ bool KFileItem::isWritable() const
     }
 
     // Or if we can't write it - not network transparent
-    if (d->m_bIsLocalUrl && !QFileInfo(d->m_url.toLocalFile()).isWritable()) {
-        return false;
+    if (d->m_bIsLocalUrl) {
+        return QFileInfo(d->m_url.toLocalFile()).isWritable();
+    } else {
+        return KProtocolManager::supportsWriting(d->m_url);
     }
-
-    return true;
 }
 
 bool KFileItem::isHidden() const
@@ -1264,6 +1254,7 @@ bool KFileItem::isFile() const
     return !isDir();
 }
 
+#if KIOCORE_BUILD_DEPRECATED_SINCE(4, 0)
 bool KFileItem::acceptsDrops() const
 {
     // A directory ?
@@ -1287,6 +1278,7 @@ bool KFileItem::acceptsDrops() const
 
     return false;
 }
+#endif
 
 QString KFileItem::getStatusBarInfo() const
 {
@@ -1391,9 +1383,10 @@ QString KFileItem::timeString(FileTimes which) const
         return QString();
     }
 
-    return d->time(which).toString();
+    return QLocale::system().toString(d->time(which), QLocale::LongFormat);
 }
 
+#if KIOCORE_BUILD_DEPRECATED_SINCE(4, 0)
 QString KFileItem::timeString(unsigned int which) const
 {
     if (!d) {
@@ -1410,11 +1403,14 @@ QString KFileItem::timeString(unsigned int which) const
         return timeString(ModificationTime);
     }
 }
+#endif
 
+#if KIOCORE_BUILD_DEPRECATED_SINCE(4, 0)
 void KFileItem::assign(const KFileItem &item)
 {
     *this = item;
 }
+#endif
 
 QUrl KFileItem::mostLocalUrl(bool *local) const
 {
@@ -1641,6 +1637,11 @@ KFileItemList::KFileItemList(const QList<KFileItem> &items)
 {
 }
 
+KFileItemList::KFileItemList(std::initializer_list<KFileItem> items)
+    : QList<KFileItem>(items)
+{
+}
+
 KFileItem KFileItemList::findByName(const QString &fileName) const
 {
     const_iterator it = begin();
