@@ -1,24 +1,11 @@
-/*****************************************************************************
- * Copyright (C) 2006-2010 by Peter Penz <peter.penz@gmx.at>                 *
- * Copyright (C) 2006 by Aaron J. Seigo <aseigo@kde.org>                     *
- * Copyright (C) 2007 by Kevin Ottens <ervin@kde.org>                        *
- * Copyright (C) 2007 by Urs Wolfer <uwolfer @ kde.org>                      *
- *                                                                           *
- * This library is free software; you can redistribute it and/or             *
- * modify it under the terms of the GNU Library General Public               *
- * License as published by the Free Software Foundation; either              *
- * version 2 of the License, or (at your option) any later version.          *
- *                                                                           *
- * This library is distributed in the hope that it will be useful,           *
- * but WITHOUT ANY WARRANTY; without even the implied warranty of            *
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU         *
- * Library General Public License for more details.                          *
- *                                                                           *
- * You should have received a copy of the GNU Library General Public License *
- * along with this library; see the file COPYING.LIB.  If not, write to      *
- * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,      *
- * Boston, MA 02110-1301, USA.                                               *
- *****************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2006-2010 Peter Penz <peter.penz@gmx.at>
+    SPDX-FileCopyrightText: 2006 Aaron J. Seigo <aseigo@kde.org>
+    SPDX-FileCopyrightText: 2007 Kevin Ottens <ervin@kde.org>
+    SPDX-FileCopyrightText: 2007 Urs Wolfer <uwolfer @ kde.org>
+
+    SPDX-License-Identifier: LGPL-2.0-or-later
+*/
 
 #include "kurlnavigator.h"
 
@@ -32,21 +19,20 @@
 
 #include <kfileitem.h>
 #include <kfileplacesmodel.h>
-#include <klocalizedstring.h>
+#include <KLocalizedString>
 #include <kprotocolinfo.h>
 #include <kurlcombobox.h>
 #include <kurlcompletion.h>
 #include <kurifilter.h>
 
 #include <QDir>
-#include <QLinkedList>
 #include <QTimer>
 #include <QApplication>
 #include <QClipboard>
 #include <QDropEvent>
 #include <QKeyEvent>
 #include <QMenu>
-#include <qmimedatabase.h>
+#include <QMimeDatabase>
 #include <QMimeData>
 #include <QHBoxLayout>
 
@@ -54,10 +40,8 @@ using namespace KDEPrivate;
 
 struct LocationData {
     QUrl url;
-#ifndef KIOFILEWIDGETS_NO_DEPRECATED
     QUrl rootUrl;      // KDE5: remove after the deprecated methods have been removed
     QPoint pos;        // KDE5: remove after the deprecated methods have been removed
-#endif
     QByteArray state;
 };
 
@@ -198,7 +182,7 @@ KUrlNavigator::Private::Private(KUrlNavigator *q, KFilePlacesModel *placesModel)
     m_showPlacesSelector(placesModel != nullptr),
     m_showFullPath(false),
     m_historyIndex(0),
-    m_layout(new QHBoxLayout),
+    m_layout(new QHBoxLayout(q)),
     m_placesSelector(nullptr),
     m_pathBox(nullptr),
     m_protocols(nullptr),
@@ -291,7 +275,6 @@ void KUrlNavigator::Private::initialize(const QUrl &url)
     const int minHeight = m_pathBox->sizeHint().height();
     q->setMinimumHeight(minHeight);
 
-    q->setLayout(m_layout);
     q->setMinimumWidth(100);
 
     updateContent();
@@ -307,11 +290,17 @@ void KUrlNavigator::Private::applyUncommittedUrl()
     // Parts of the following code have been taken
     // from the class KateFileSelector located in
     // kate/app/katefileselector.hpp of Kate.
-    // Copyright (C) 2001 Christoph Cullmann <cullmann@kde.org>
-    // Copyright (C) 2001 Joseph Wenninger <jowenn@kde.org>
-    // Copyright (C) 2001 Anders Lund <anders.lund@lund.tdcadsl.dk>
+    // SPDX-FileCopyrightText: 2001 Christoph Cullmann <cullmann@kde.org>
+    // SPDX-FileCopyrightText: 2001 Joseph Wenninger <jowenn@kde.org>
+    // SPDX-FileCopyrightText: 2001 Anders Lund <anders.lund@lund.tdcadsl.dk>
+
+    QUrl typedUrl = q->uncommittedUrl();
+    // For example "desktop:/" _not_ "desktop:", see the comment in slotProtocolChanged()
+    if (!typedUrl.isEmpty() && typedUrl.path().isEmpty()
+        && KProtocolInfo::protocolClass(typedUrl.scheme()) == QLatin1String(":local")) {
+        typedUrl.setPath(QStringLiteral("/"));
+    }
 
-    const QUrl typedUrl = q->uncommittedUrl();
     QStringList urls = m_pathBox->urls();
     urls.removeAll(typedUrl.toString());
     urls.prepend(typedUrl.toString());
@@ -344,7 +333,10 @@ void KUrlNavigator::Private::slotProtocolChanged(const QString &protocol)
 
     QUrl url;
     url.setScheme(protocol);
-    if (protocol == QLatin1String("file")) {
+    if (KProtocolInfo::protocolClass(protocol) == QLatin1String(":local")) {
+        // E.g. "file:/" or "desktop:/", _not_ "file:" or "desktop:" respectively.
+        // This is the more expected behaviour, "file:somedir" treats somedir as
+        // a path relative to current dir; file:/somedir is an absolute path to /somedir.
         url.setPath(QStringLiteral("/"));
     } else {
         // With no authority set we'll get e.g. "ftp:" instead of "ftp://".
@@ -447,7 +439,7 @@ void KUrlNavigator::Private::dropUrls(const QUrl &destination, QDropEvent *event
 
 void KUrlNavigator::Private::slotNavigatorButtonClicked(const QUrl &url, Qt::MouseButton button, Qt::KeyboardModifiers modifiers)
 {
-    if (button & Qt::MidButton || (button & Qt::LeftButton && modifiers & Qt::ControlModifier)) {
+    if (button & Qt::MiddleButton || (button & Qt::LeftButton && modifiers & Qt::ControlModifier)) {
         emit q->tabRequested(url);
     } else if (button & Qt::LeftButton) {
         q->setLocationUrl(url);
@@ -683,7 +675,7 @@ void KUrlNavigator::Private::updateButtonVisibility()
 
     // Check whether buttons must be hidden at all...
     int requiredButtonWidth = 0;
-    foreach (const KUrlNavigatorButton *button, m_navButtons) {
+    for (const KUrlNavigatorButton *button : qAsConst(m_navButtons)) {
         requiredButtonWidth += button->minimumWidth();
     }
 
@@ -700,7 +692,7 @@ void KUrlNavigator::Private::updateButtonVisibility()
     bool isLastButton = true;
     bool hasHiddenButtons = false;
 
-    QLinkedList<KUrlNavigatorButton *> buttonsToShow;
+    QList<KUrlNavigatorButton *> buttonsToShow;
     while (it != itBegin) {
         --it;
         KUrlNavigatorButton *button = (*it);
@@ -721,7 +713,7 @@ void KUrlNavigator::Private::updateButtonVisibility()
 
     // All buttons have the correct activation state and
     // can be shown now
-    foreach (KUrlNavigatorButton *button, buttonsToShow) {
+    for (KUrlNavigatorButton *button : qAsConst(buttonsToShow)) {
         button->show();
     }
 
@@ -800,7 +792,7 @@ void KUrlNavigator::Private::switchToBreadcrumbMode()
 
 void KUrlNavigator::Private::deleteButtons()
 {
-    foreach (KUrlNavigatorButton *button, m_navButtons) {
+    for (KUrlNavigatorButton *button : qAsConst(m_navButtons)) {
         button->hide();
         button->deleteLater();
     }
@@ -828,8 +820,10 @@ bool KUrlNavigator::Private::isCompressedPath(const QUrl &url) const
             mime.inherits(QStringLiteral("application/x-tzo")) || // (not sure KTar supports those?)
             mime.inherits(QStringLiteral("application/zip")) ||
             mime.inherits(QStringLiteral("application/x-archive")) ||
-            mime.inherits(QStringLiteral("application/vnd.rar")) || // the following depends on krarc
-            mime.inherits(QStringLiteral("application/x-7z-compressed")) ||
+            mime.inherits(QStringLiteral("application/x-7z-compressed")) || // the following depends on krarc
+            mime.inherits(QStringLiteral("application/x-rpm")) ||
+            mime.inherits(QStringLiteral("application/x-source-rpm")) ||
+            mime.inherits(QStringLiteral("application/vnd.rar")) ||
             mime.inherits(QStringLiteral("application/x-ace")) ||
             mime.inherits(QStringLiteral("application/x-arj")) ||
             mime.inherits(QStringLiteral("application/x-cpio")) ||
@@ -992,7 +986,7 @@ void KUrlNavigator::setActive(bool active)
         d->m_active = active;
 
         d->m_dropDownButton->setActive(active);
-        foreach (KUrlNavigatorButton *button, d->m_navButtons) {
+        for (KUrlNavigatorButton *button : qAsConst(d->m_navButtons)) {
             button->setActive(active);
         }
 
@@ -1052,8 +1046,8 @@ void KUrlNavigator::setLocationUrl(const QUrl &newUrl)
     // code locationUrl() and url become the same URLs
     QUrl firstChildUrl = KIO::UrlUtil::firstChildUrl(locationUrl(), url);
 
-    if ((url.scheme() == QLatin1String("tar")) || (url.scheme() == QLatin1String("zip")) || (url.scheme() == QLatin1String("krarc"))) {
-        // The URL represents a tar- or zip-file, or an archive file supported by krarc.
+    if ((url.scheme() == QLatin1String("tar")) || (url.scheme() == QLatin1String("zip")) || (url.scheme() == QLatin1String("sevenz")) || (url.scheme() == QLatin1String("krarc"))) {
+        // The URL represents a tar-, zip- or 7z-file, or an archive file supported by krarc.
         // Check whether the URL is really part of the archive file, otherwise
         // replace it by the local path again.
         bool insideCompressedPath = d->isCompressedPath(url);
@@ -1070,7 +1064,7 @@ void KUrlNavigator::setLocationUrl(const QUrl &newUrl)
             }
         }
         if (!insideCompressedPath) {
-            // drop the tar: or zip: or krarc: protocol since we are not
+            // drop the tar:, zip:, sevenz: or krarc: protocol since we are not
             // inside the compressed path
             url.setScheme(QStringLiteral("file"));
             firstChildUrl.setScheme(QStringLiteral("file"));
@@ -1138,7 +1132,7 @@ void KUrlNavigator::setFocus()
     }
 }
 
-#ifndef KIOFILEWIDGETS_NO_DEPRECATED
+#if KIOFILEWIDGETS_BUILD_DEPRECATED_SINCE(4, 5)
 void KUrlNavigator::setUrl(const QUrl &url)
 {
     // deprecated
@@ -1146,7 +1140,7 @@ void KUrlNavigator::setUrl(const QUrl &url)
 }
 #endif
 
-#ifndef KIOFILEWIDGETS_NO_DEPRECATED
+#if KIOFILEWIDGETS_BUILD_DEPRECATED_SINCE(4, 5)
 void KUrlNavigator::saveRootUrl(const QUrl &url)
 {
     // deprecated
@@ -1154,7 +1148,7 @@ void KUrlNavigator::saveRootUrl(const QUrl &url)
 }
 #endif
 
-#ifndef KIOFILEWIDGETS_NO_DEPRECATED
+#if KIOFILEWIDGETS_BUILD_DEPRECATED_SINCE(4, 5)
 void KUrlNavigator::savePosition(int x, int y)
 {
     // deprecated
@@ -1186,7 +1180,7 @@ void KUrlNavigator::mousePressEvent(QMouseEvent *event)
 
 void KUrlNavigator::mouseReleaseEvent(QMouseEvent *event)
 {
-    if (event->button() == Qt::MidButton) {
+    if (event->button() == Qt::MiddleButton) {
         const QRect bounds = d->m_toggleEditableMode->geometry();
         if (bounds.contains(event->pos())) {
             // The middle mouse button has been clicked above the
@@ -1223,13 +1217,13 @@ bool KUrlNavigator::eventFilter(QObject *watched, QEvent *event)
             requestActivation();
             setFocus();
         }
-        foreach (KUrlNavigatorButton *button, d->m_navButtons) {
+        for (KUrlNavigatorButton *button : qAsConst(d->m_navButtons)) {
             button->setShowMnemonic(true);
         }
         break;
 
     case QEvent::FocusOut:
-        foreach (KUrlNavigatorButton *button, d->m_navButtons) {
+        for (KUrlNavigatorButton *button : qAsConst(d->m_navButtons)) {
             button->setShowMnemonic(false);
         }
         break;
@@ -1272,7 +1266,7 @@ QWidget *KUrlNavigator::dropWidget() const
     return d->m_dropWidget;
 }
 
-#ifndef KIOFILEWIDGETS_NO_DEPRECATED
+#if KIOFILEWIDGETS_BUILD_DEPRECATED_SINCE(4, 5)
 const QUrl &KUrlNavigator::url() const
 {
     // deprecated
@@ -1285,7 +1279,7 @@ const QUrl &KUrlNavigator::url() const
 }
 #endif
 
-#ifndef KIOFILEWIDGETS_NO_DEPRECATED
+#if KIOFILEWIDGETS_BUILD_DEPRECATED_SINCE(4, 5)
 QUrl KUrlNavigator::url(int index) const
 {
     // deprecated
@@ -1293,7 +1287,7 @@ QUrl KUrlNavigator::url(int index) const
 }
 #endif
 
-#ifndef KIOFILEWIDGETS_NO_DEPRECATED
+#if KIOFILEWIDGETS_BUILD_DEPRECATED_SINCE(4, 5)
 QUrl KUrlNavigator::historyUrl(int historyIndex) const
 {
     // deprecated
@@ -1301,7 +1295,7 @@ QUrl KUrlNavigator::historyUrl(int historyIndex) const
 }
 #endif
 
-#ifndef KIOFILEWIDGETS_NO_DEPRECATED
+#if KIOFILEWIDGETS_BUILD_DEPRECATED_SINCE(4, 5)
 const QUrl &KUrlNavigator::savedRootUrl() const
 {
     // deprecated
@@ -1314,7 +1308,7 @@ const QUrl &KUrlNavigator::savedRootUrl() const
 }
 #endif
 
-#ifndef KIOFILEWIDGETS_NO_DEPRECATED
+#if KIOFILEWIDGETS_BUILD_DEPRECATED_SINCE(4, 5)
 QPoint KUrlNavigator::savedPosition() const
 {
     // deprecated
@@ -1322,7 +1316,7 @@ QPoint KUrlNavigator::savedPosition() const
 }
 #endif
 
-#ifndef KIOFILEWIDGETS_NO_DEPRECATED
+#if KIOFILEWIDGETS_BUILD_DEPRECATED_SINCE(4, 5)
 void KUrlNavigator::setHomeUrl(const QString &homeUrl)
 {
     // deprecated
