@@ -1,34 +1,21 @@
 /*
-   Copyright (C) 2000,2001 Dawit Alemayehu <adawit@kde.org>
-   Copyright (C) 2000,2001 Waldo Bastian <bastian@kde.org>
-   Copyright (C) 2000,2001 George Staikos <staikos@kde.org>
-   Copyright (C) 2001,2002 Hamish Rodda <rodda@kde.org>
-   Copyright (C) 2007      Daniel Nicoletti <mirttex@users.sourceforge.net>
-   Copyright (C) 2008,2009 Andreas Hartmetz <ahartmetz@gmail.com>
+    SPDX-FileCopyrightText: 2000, 2001 Dawit Alemayehu <adawit@kde.org>
+    SPDX-FileCopyrightText: 2000, 2001 Waldo Bastian <bastian@kde.org>
+    SPDX-FileCopyrightText: 2000, 2001 George Staikos <staikos@kde.org>
+    SPDX-FileCopyrightText: 2001, 2002 Hamish Rodda <rodda@kde.org>
+    SPDX-FileCopyrightText: 2007 Daniel Nicoletti <mirttex@users.sourceforge.net>
+    SPDX-FileCopyrightText: 2008, 2009 Andreas Hartmetz <ahartmetz@gmail.com>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #ifndef HTTP_H
 #define HTTP_H
 
-#include <QtCore/QList>
-#include <QtCore/QStringList>
-#include <QtCore/QDateTime>
-#include <QtNetwork/QLocalSocket>
+#include <QList>
+#include <QStringList>
+#include <QDateTime>
+#include <QLocalSocket>
 #include <QUrl>
 
 #include "kio/tcpslavebase.h"
@@ -85,7 +72,7 @@ public:
             useCache = false;
             ioMode = NoCache;
             bytesCached = 0;
-            file = 0;
+            file = nullptr;
         }
 
         enum CachePlan {
@@ -220,20 +207,20 @@ public:
 
 //---------------------- Re-implemented methods ----------------
     virtual void setHost(const QString &host, quint16 port, const QString &user,
-                         const QString &pass) Q_DECL_OVERRIDE;
+                         const QString &pass) override;
 
-    void slave_status() Q_DECL_OVERRIDE;
+    void slave_status() override;
 
-    void get(const QUrl &url) Q_DECL_OVERRIDE;
-    void put(const QUrl &url, int _mode, KIO::JobFlags flags) Q_DECL_OVERRIDE;
+    void get(const QUrl &url) override;
+    void put(const QUrl &url, int _mode, KIO::JobFlags flags) override;
 
 //----------------- Re-implemented methods for WebDAV -----------
-    void listDir(const QUrl &url) Q_DECL_OVERRIDE;
-    void mkdir(const QUrl &url, int _permissions) Q_DECL_OVERRIDE;
+    void listDir(const QUrl &url) override;
+    void mkdir(const QUrl &url, int _permissions) override;
 
-    void rename(const QUrl &src, const QUrl &dest, KIO::JobFlags flags) Q_DECL_OVERRIDE;
-    void copy(const QUrl &src, const QUrl &dest, int _permissions, KIO::JobFlags flags) Q_DECL_OVERRIDE;
-    void del(const QUrl &url, bool _isfile) Q_DECL_OVERRIDE;
+    void rename(const QUrl &src, const QUrl &dest, KIO::JobFlags flags) override;
+    void copy(const QUrl &src, const QUrl &dest, int _permissions, KIO::JobFlags flags) override;
+    void del(const QUrl &url, bool _isfile) override;
 
     // ask the host whether it supports WebDAV & cache this info
     bool davHostOk();
@@ -262,21 +249,21 @@ public:
      * 5 - DAV LOCK     (see
      * 6 - DAV UNLOCK     README.webdav)
      */
-    void special(const QByteArray &data) Q_DECL_OVERRIDE;
+    void special(const QByteArray &data) override;
 
-    void mimetype(const QUrl &url) Q_DECL_OVERRIDE;
+    void mimetype(const QUrl &url) override;
 
-    void stat(const QUrl &url) Q_DECL_OVERRIDE;
+    void stat(const QUrl &url) override;
 
-    void reparseConfiguration() Q_DECL_OVERRIDE;
+    void reparseConfiguration() override;
 
     /**
      * Forced close of connection
      */
-    void closeConnection() Q_DECL_OVERRIDE;
+    void closeConnection() override;
 
     void post(const QUrl &url, qint64 size = -1);
-    void multiGet(const QByteArray &data) Q_DECL_OVERRIDE;
+    void multiGet(const QByteArray &data) override;
     bool maybeSetRequestUrl(const QUrl &);
 
     /**
@@ -315,7 +302,7 @@ protected:
 
     /**
       * Add an encoding on to the appropriate stack this
-      * is nececesary because transfer encodings and
+      * is necessary because transfer encodings and
       * content encodings must be handled separately.
       */
     void addEncoding(const QString &, QStringList &);
@@ -506,16 +493,30 @@ protected:
     void copyPut(const QUrl& src, const QUrl& dest, KIO::JobFlags flags);
 
     /**
-      * Stats a remote DAV file and returns true if it exists.
+      * Stats a remote DAV file and returns true if it already exists.
       */
-    bool davStatDestination();
+    bool davDestinationExists();
 
-    void virtual_hook(int id, void *data) Q_DECL_OVERRIDE;
+    void virtual_hook(int id, void *data) override;
 
 private:
     void fileSystemFreeSpace(const QUrl &url); // KF6 TODO: Once a virtual fileSystemFreeSpace method in SlaveBase exists, override it
 
 protected:
+    /* This stores information about the credentials already tried
+     * during the authentication stage (in case the auth method uses
+     * a username and password). Initially the job-provided credentials
+     * are used (if any). In case of failure the credential cache is
+     * queried and if this fails the user is asked to provide credentials
+     * interactively (unless forbidden by metadata) */
+    enum TriedCredentials
+    {
+        NoCredentials = 0,
+        JobCredentials,
+        CachedCredentials,
+        UserInputCredentials
+    };
+
     HTTPServerState m_server;
     HTTPRequest m_request;
     QList<HTTPRequest> m_requestQueue;
@@ -557,7 +558,7 @@ protected:
     QByteArray m_mimeTypeBuffer;
 
     // Holds the POST data so it won't get lost on if we
-    // happend to get a 401/407 response when submitting
+    // happenned to get a 401/407 response when submitting
     // a form.
     QIODevice *m_POSTbuf;
 
@@ -571,15 +572,19 @@ protected:
     QByteArray m_protocol;
 
     KAbstractHttpAuthentication *m_wwwAuth;
+    QList<QByteArray> m_blacklistedWwwAuthMethods;
+    TriedCredentials m_triedWwwCredentials;
     KAbstractHttpAuthentication *m_proxyAuth;
+    QList<QByteArray> m_blacklistedProxyAuthMethods;
+    TriedCredentials m_triedProxyCredentials;
     // For proxy auth when it's handled by the Qt/KDE socket classes
     QAuthenticator *m_socketProxyAuth;
 
     // To know if we are online or not
     QNetworkConfigurationManager *m_networkConfig;
-    // Indicates whether there was some error.
-    int m_iError;
-    // Whether we are loading an error page (we should close the connection afterwards)
+    // The current KIO error on this request / response pair - zero / KJob::NoError if no error
+    int m_kioError;
+    // Whether we are loading an error page (body of a reply with error response code)
     bool m_isLoadingErrorPage;
 
     // Values that determine the remote connection timeouts.
