@@ -1,28 +1,11 @@
 /*
-This file is part of KDE
+    This file is part of KDE
+    SPDX-FileCopyrightText: 1999-2000 Waldo Bastian <bastian@kde.org>
+    SPDX-FileCopyrightText: 2009 Andreas Hartmetz <ahartmetz@gmail.com>
 
- Copyright (C) 1999-2000 Waldo Bastian (bastian@kde.org)
- Copyright (C) 2009 Andreas Hartmetz (ahartmetz@gmail.com)
-
-Permission is hereby granted, free of charge, to any person obtaining a copy
-of this software and associated documentation files (the "Software"), to deal
-in the Software without restriction, including without limitation the rights
-to use, copy, modify, merge, publish, distribute, and/or sell
-copies of the Software, and to permit persons to whom the Software is
-furnished to do so, subject to the following conditions:
-
-The above copyright notice and this permission notice shall be included in
-all copies or substantial portions of the Software.
-
-THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
-IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
-FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL THE
-AUTHORS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN
-AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
-CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+    SPDX-License-Identifier: MIT
 */
-//----------------------------------------------------------------------------
-//
+
 // KDE HTTP Cache cleanup tool
 
 #include <cstring>
@@ -37,13 +20,13 @@ CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 #include <QLocalSocket>
 
 #include <QDebug>
-#include <klocalizedstring.h>
+#include <KLocalizedString>
 #include <kprotocolmanager.h>
 
 #include <qplatformdefs.h>
-#include <qstandardpaths.h>
-#include <qcommandlineparser.h>
-#include <qcommandlineoption.h>
+#include <QStandardPaths>
+#include <QCommandLineParser>
+#include <QCommandLineOption>
 #include <QCryptographicHash>
 #include <QDBusError>
 #include <QDataStream>
@@ -598,17 +581,12 @@ static void removeOldFiles()
 {
     const char *oldDirs = "0abcdefghijklmnopqrstuvwxyz";
     const int n = strlen(oldDirs);
-    QDir cacheRootDir(filePath(QString()));
-    for (int i = 0; i < n; i++) {
-        QString dirName = QString::fromLatin1(&oldDirs[i], 1);
-        // delete files in directory...
-        Q_FOREACH (const QString &baseName, QDir(filePath(dirName)).entryList()) {
-            QFile::remove(filePath(dirName + QLatin1Char('/') + baseName));
-        }
-        // delete the (now hopefully empty!) directory itself
-        cacheRootDir.rmdir(dirName);
+    const QString cacheRootDir = filePath(QString());
+    for (int i = 0; i < n; ++i) {
+        const QString dirName = QString::fromLatin1(&oldDirs[i], 1);
+        QDir(cacheRootDir + dirName).removeRecursively();
     }
-    QFile::remove(filePath(QStringLiteral("cleaned")));
+    QFile::remove(cacheRootDir + QLatin1String("cleaned"));
 }
 
 class CacheCleaner
@@ -725,8 +703,12 @@ int main(int argc, char **argv)
     parser.addVersionOption();
     parser.setApplicationDescription(QCoreApplication::translate("main", "KDE HTTP cache maintenance tool"));
     parser.addHelpOption();
-    parser.addOption(QCommandLineOption(QStringList() << QStringLiteral("clear-all"), QCoreApplication::translate("main", "Empty the cache")));
-    parser.addOption(QCommandLineOption(QStringList() << QStringLiteral("file-info"), QCoreApplication::translate("main", "Display information about cache file"), QStringLiteral("filename")));
+    parser.addOption(QCommandLineOption(QStringList{QStringLiteral("clear-all")},
+                                        QCoreApplication::translate("main", "Empty the cache")));
+    parser.addOption(QCommandLineOption(
+        QStringList{QStringLiteral("file-info")},
+        QCoreApplication::translate("main", "Display information about cache file"),
+        QStringLiteral("filename")));
     parser.process(app);
 
     OperationMode mode = CleanCache;
