@@ -1,22 +1,9 @@
-/***************************************************************************
- *   Copyright (C) 2005 by Sean Harmer <sh@rama.homelinux.org>             *
- *                 2005 - 2007 Till Adam <adam@kde.org>                    *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU Library General Public License as       *
- *   published by  the Free Software Foundation; either version 2 of the   *
- *   License, or (at your option) any later version.                       *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the                         *
- *   Free Software Foundation, Inc.,                                       *
- *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.             *
- ***************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2005 Sean Harmer <sh@rama.homelinux.org>
+    SPDX-FileCopyrightText: 2005-2007 Till Adam <adam@kde.org>
+
+    SPDX-License-Identifier: LGPL-2.0-or-later
+*/
 
 #include "kacleditwidget.h"
 #include "kacleditwidget_p.h"
@@ -26,22 +13,21 @@
 
 #include <QDialog>
 #include <QDialogButtonBox>
-#include <qpainter.h>
-#include <qpushbutton.h>
+#include <QPainter>
+#include <QPushButton>
 #include <QButtonGroup>
 #include <QGroupBox>
-#include <qradiobutton.h>
-#include <qcombobox.h>
-#include <qlabel.h>
-#include <qcheckbox.h>
-#include <qlayout.h>
+#include <QRadioButton>
+#include <QComboBox>
+#include <QLabel>
+#include <QCheckBox>
+#include <QLayout>
 #include <QStackedWidget>
 #include <QMouseEvent>
 #include <QHeaderView>
 
-#include <klocalizedstring.h>
+#include <KLocalizedString>
 #include <kfileitem.h>
-#include <QDebug>
 
 #if HAVE_ACL_LIBACL_H
 # include <acl/libacl.h>
@@ -52,19 +38,6 @@ extern "C" {
 }
 #include <assert.h>
 
-static struct {
-    const char *label;
-    const char *pixmapName;
-    QPixmap *pixmap;
-} s_itemAttributes[] = {
-    { I18N_NOOP("Owner"), "user-grey", nullptr },
-    { I18N_NOOP("Owning Group"), "group-grey", nullptr },
-    { I18N_NOOP("Others"), "others-grey", nullptr },
-    { I18N_NOOP("Mask"), "mask", nullptr },
-    { I18N_NOOP("Named User"), "user", nullptr },
-    { I18N_NOOP("Named Group"), "group", nullptr },
-};
-
 class KACLEditWidget::KACLEditWidgetPrivate
 {
 public:
@@ -217,61 +190,30 @@ bool KACLListViewItem::operator< (const QTreeWidgetItem &other) const
     return key() < static_cast<const KACLListViewItem &>(other).key();
 }
 
-#if 0
-void KACLListViewItem::paintCell(QPainter *p, const QColorGroup &cg,
-                                 int column, int width, int alignment)
-{
-    if (isDefault) {
-        setForeground(QColor(0, 0, 255));
-    }
-    if (isPartial) {
-        QFont font = p->font();
-        font.setItalic(true);
-        setForeground(QColor(100, 100, 100));
-        p->setFont(font);
-    }
-    QTreeWidgetItem::paintCell(p, mycg, column, width, alignment);
-
-    KACLListViewItem *below = 0;
-    if (itemBelow()) {
-        below = static_cast<KACLListViewItem *>(itemBelow());
-    }
-    const bool lastUser = type == KACLListView::NamedUser && below && below->type == KACLListView::NamedGroup;
-    const bool lastNonDefault = !isDefault && below && below->isDefault;
-    if (type == KACLListView::Mask || lastUser || lastNonDefault) {
-        p->setPen(QPen(Qt::gray, 0, Qt::DotLine));
-        if (type == KACLListView::Mask) {
-            p->drawLine(0, 0, width - 1, 0);
-        }
-        p->drawLine(0, height() - 1, width - 1, height() - 1);
-    }
-}
-#endif
-
-void KACLListViewItem::updatePermPixmaps()
+void KACLListViewItem::updatePermissionIcons()
 {
     unsigned int partialPerms = value;
 
     if (value & ACL_READ) {
-        setIcon(2, m_pACLListView->getYesPixmap());
+        setIcon(2, QIcon::fromTheme(QStringLiteral("checkmark")));
     } else if (partialPerms & ACL_READ) {
-        setIcon(2, m_pACLListView->getYesPartialPixmap());
+        setIcon(2, QIcon::fromTheme(QStringLiteral("checkmark-partial")));
     } else {
         setIcon(2, QIcon());
     }
 
     if (value & ACL_WRITE) {
-        setIcon(3, m_pACLListView->getYesPixmap());
+        setIcon(3, QIcon::fromTheme(QStringLiteral("checkmark")));
     } else if (partialPerms & ACL_WRITE) {
-        setIcon(3, m_pACLListView->getYesPartialPixmap());
+        setIcon(3, QIcon::fromTheme(QStringLiteral("checkmark-partial")));
     } else {
         setIcon(3, QIcon());
     }
 
     if (value & ACL_EXECUTE) {
-        setIcon(4, m_pACLListView->getYesPixmap());
+        setIcon(4, QIcon::fromTheme(QStringLiteral("checkmark")));
     } else if (partialPerms & ACL_EXECUTE) {
-        setIcon(4, m_pACLListView->getYesPartialPixmap());
+        setIcon(4, QIcon::fromTheme(QStringLiteral("checkmark-partial")));
     } else {
         setIcon(4, QIcon());
     }
@@ -279,38 +221,44 @@ void KACLListViewItem::updatePermPixmaps()
 
 void KACLListViewItem::repaint()
 {
-    int idx = 0;
+    QString text;
+    QString icon;
+
     switch (type) {
     case KACLListView::User:
-        idx = KACLListView::OWNER_IDX;
+    default:
+        text = i18nc("Unix permissions", "Owner");
+        icon = QStringLiteral("user-gray");
         break;
     case KACLListView::Group:
-        idx = KACLListView::GROUP_IDX;
+        text = i18nc("UNIX permissions", "Owning Group");
+        icon = QStringLiteral("group-gray");
         break;
     case KACLListView::Others:
-        idx = KACLListView::OTHERS_IDX;
+        text = i18nc("UNIX permissions", "Others");
+        icon = QStringLiteral("user-others-gray");
         break;
     case KACLListView::Mask:
-        idx = KACLListView::MASK_IDX;
+        text = i18nc("UNIX permissions", "Mask");
+        icon = QStringLiteral("view-filter");
         break;
     case KACLListView::NamedUser:
-        idx = KACLListView::NAMED_USER_IDX;
+        text = i18nc("UNIX permissions", "Named User");
+        icon = QStringLiteral("user");
         break;
     case KACLListView::NamedGroup:
-        idx = KACLListView::NAMED_GROUP_IDX;
-        break;
-    default:
-        idx = KACLListView::OWNER_IDX;
+        text = i18nc("UNIX permissions", "Others");
+        icon = QStringLiteral("user-others");
         break;
     }
-    setText(0, i18n(s_itemAttributes[idx].label));
-    setIcon(0, *s_itemAttributes[idx].pixmap);
+    setText(0, text);
+    setIcon(0, QIcon::fromTheme(icon));
     if (isDefault) {
-        setText(0, text(0) + i18n(" (Default)"));
+        setText(0, i18n("Owner (Default)"));
     }
     setText(1, qualifier);
-    // Set the pixmaps for which of the perms are set
-    updatePermPixmaps();
+    // Set the icons for which of the perms are set
+    updatePermissionIcons();
 }
 
 void KACLListViewItem::calcEffectiveRights()
@@ -325,9 +273,9 @@ void KACLListViewItem::calcEffectiveRights()
                 || type == KACLListView::NamedGroup)
             && !isDefault) {
 
-        strEffective[0] = (m_pACLListView->maskPermissions() & value & ACL_READ) ? 'r' : '-';
-        strEffective[1] = (m_pACLListView->maskPermissions() & value & ACL_WRITE) ? 'w' : '-';
-        strEffective[2] = (m_pACLListView->maskPermissions() & value & ACL_EXECUTE) ? 'x' : '-';
+        strEffective[0] = QLatin1Char((m_pACLListView->maskPermissions() & value & ACL_READ) ? 'r' : '-');
+        strEffective[1] = QLatin1Char((m_pACLListView->maskPermissions() & value & ACL_WRITE) ? 'w' : '-');
+        strEffective[2] = QLatin1Char((m_pACLListView->maskPermissions() & value & ACL_EXECUTE) ? 'x' : '-');
         /*
                 // What about any partial perms?
                 if ( maskPerms & partialPerms & ACL_READ || // Partial perms on entry
@@ -345,9 +293,9 @@ void KACLListViewItem::calcEffectiveRights()
         */
     } else {
         // No, the effective value are just the value in this entry
-        strEffective[0] = (value & ACL_READ) ? 'r' : '-';
-        strEffective[1] = (value & ACL_WRITE) ? 'w' : '-';
-        strEffective[2] = (value & ACL_EXECUTE) ? 'x' : '-';
+        strEffective[0] = QLatin1Char((value & ACL_READ) ? 'r' : '-');
+        strEffective[1] = QLatin1Char((value & ACL_WRITE) ? 'w' : '-');
+        strEffective[2] = QLatin1Char((value & ACL_EXECUTE) ? 'x' : '-');
 
         /*
         // What about any partial perms?
@@ -393,7 +341,7 @@ void KACLListViewItem::togglePerm(acl_perm_t perm)
         m_pACLListView->setMaskPermissions(value);
     }
     calcEffectiveRights();
-    updatePermPixmaps();
+    updatePermissionIcons();
     /*
         // If the perm is in the partial perms then remove it. i.e. Once
         // a user changes a partial perm it then applies to all selected files.
@@ -429,8 +377,7 @@ EditACLEntryDialog::EditACLEntryDialog(KACLListView *listView, KACLListViewItem
     setModal(true);
     setWindowTitle(i18n("Edit ACL Entry"));
 
-    QVBoxLayout *mainLayout = new QVBoxLayout;
-    setLayout(mainLayout);
+    QVBoxLayout *mainLayout = new QVBoxLayout(this);
     QGroupBox *gb = new QGroupBox(i18n("Entry Type"), this);
     QVBoxLayout *gbLayout = new QVBoxLayout(gb);
 
@@ -488,11 +435,10 @@ EditACLEntryDialog::EditACLEntryDialog(KACLListView *listView, KACLListViewItem
     // users box
     QWidget *usersBox = new QWidget(m_widgetStack);
     QHBoxLayout *usersLayout = new QHBoxLayout(usersBox);
-    usersBox->setLayout(usersLayout);
     m_widgetStack->addWidget(usersBox);
 
     QLabel *usersLabel = new QLabel(i18n("User: "), usersBox);
-    m_usersCombo = new KComboBox(usersBox);
+    m_usersCombo = new QComboBox(usersBox);
     m_usersCombo->setEditable(false);
     m_usersCombo->setObjectName(QStringLiteral("users"));
     usersLabel->setBuddy(m_usersCombo);
@@ -503,11 +449,10 @@ EditACLEntryDialog::EditACLEntryDialog(KACLListView *listView, KACLListViewItem
     // groups box
     QWidget *groupsBox = new QWidget(m_widgetStack);
     QHBoxLayout *groupsLayout = new QHBoxLayout(usersBox);
-    groupsBox->setLayout(groupsLayout);
     m_widgetStack->addWidget(groupsBox);
 
     QLabel *groupsLabel = new QLabel(i18n("Group: "), groupsBox);
-    m_groupsCombo = new KComboBox(groupsBox);
+    m_groupsCombo = new QComboBox(groupsBox);
     m_groupsCombo->setEditable(false);
     m_groupsCombo->setObjectName(QStringLiteral("groups"));
     groupsLabel->setBuddy(m_groupsCombo);
@@ -657,13 +602,6 @@ KACLListView::KACLListView(QWidget *parent)
     header()->setSectionResizeMode(QHeaderView::ResizeToContents);
     setRootIsDecorated(false);
 
-    // Load the avatars
-    for (int i = 0; i < LAST_IDX; ++i) {
-        s_itemAttributes[i].pixmap = new QPixmap(QLatin1String(":/images/") + QLatin1String(s_itemAttributes[i].pixmapName));
-    }
-    m_yesPixmap = new QPixmap(QStringLiteral(":/images/yes.png"));
-    m_yesPartialPixmap = new QPixmap(QStringLiteral(":/images/yespartial.png"));
-
     // fill the lists of all legal users and groups
     struct passwd *user = nullptr;
     setpwent();
@@ -690,11 +628,6 @@ KACLListView::KACLListView(QWidget *parent)
 
 KACLListView::~KACLListView()
 {
-    for (int i = 0; i < LAST_IDX; ++i) {
-        delete s_itemAttributes[i].pixmap;
-    }
-    delete m_yesPixmap;
-    delete m_yesPartialPixmap;
 }
 
 QStringList KACLListView::allowedUsers(bool defaults, KACLListViewItem *allowedItem)
